function gfd = LFmodel(Tp, Te, Tc, Ta, T, Ee, N)
%
% LF model for glottal flow derivative (gfd). All the parameters are in
% samples. The equations used are eq. (2) & (3) of Fu an Murphy's paper
% with title "Robust Glottal Source Estimation Based on Joint Source-Filter
% Model Optimization" (2006).
%
%  ----INPUT PARAMETERS----
%    Tp: time instant where maximum value of glottal flow occurs
%    Te: glottal closure instant (maximum negative value of gfd)
%    Tc: end of return phase
%    Ta: return phase interval
%    T: pich period
%    Ee: the maximum negative value of the gfd
%    N: how many pitch periods to construct
%
%  ----OUTPUT PARAMENTERS----
%    gfd: Glottal flow derivative
%
% (c) Yannis Pantazis, 2006, csd, uoc
%     mail: pantazis@csd.uoc.gr

n = 1:T;
gfd = zeros(1,T);

Wg = pi/Tp;

fb = @(betta) 1 - exp(-betta*(Tc-Te)) - betta*Ta;
inb = 2*log((Tc-Te)/Ta)/(Tc-Te);

betta = fzero(fb, inb);

C = (1-exp(-betta*(Tc-Te)))/(betta^2*Ta) - (Tc-Te)*exp(-betta*(Tc-Te))/(betta*Ta);

fa = @(alpha) (alpha^2+Wg^2)*sin(Wg*Te)*C + Wg*exp(-alpha*Te) + alpha*sin(Wg*Te) - Wg*cos(Wg*Te);
ina = inb;

alpha = fzero(fa, ina);

E0 = -Ee/(exp(alpha*Te)*sin(Wg*Te));

gfd(1:Te) = E0*exp(alpha*n(1:Te)).*sin(Wg*n(1:Te));
gfd(Te+1:Tc) = -Ee/(betta*Ta)*(exp(-betta*n(1:(Tc-Te))) - exp(-betta*(Tc-Te)));
gfd = repmat(gfd, 1, N);

